@@ -13,7 +13,7 @@ It provides functionality for
 """
 from datetime import date, datetime
 from enum import Enum
-from typing import Any, Callable, Dict, Generator, Optional
+from typing import Callable, Generator, Optional
 
 from xknx.remote_value import RemoteValue, RemoteValueSensor, RemoteValueSwitch
 
@@ -189,7 +189,7 @@ class Weather(Device):
             xknx,
             group_address_state=group_address_air_pressure,
             sync_state=sync_state,
-            value_type="pressure",
+            value_type="pressure_2byte",
             device_name=self.name,
             feature_name="Air pressure",
             after_update_cb=self.after_update,
@@ -451,19 +451,6 @@ class Weather(Device):
 
         return WeatherCondition.exceptional
 
-    @property
-    def ha_state_attributes(self) -> Optional[Dict[str, Any]]:
-        """Return device specific state attributes."""
-        return {
-            "brightness_south": self.brightness_south,
-            "brightness_north": self.brightness_north,
-            "brightness_east": self.brightness_east,
-            "brightness_west": self.brightness_west,
-            "wind_alarm": self.wind_alarm,
-            "frost_alarm": self.frost_alarm,
-            "rain_alarm": self.rain_alarm,
-        }
-
     @classmethod
     def from_config(cls, xknx, name, config):
         """Initialize object from configuration structure."""
