@@ -10,37 +10,39 @@ from xknx.exceptions import CouldNotParseTelegram
 from xknx.telegram import GroupAddress, Telegram, TelegramType
 
 
-class RemoteValue():
+class RemoteValue:
     """Class for managing remote knx value."""
 
     # pylint: disable=too-many-instance-attributes
-    def __init__(self,
-                 xknx,
-                 group_address=None,
-                 group_address_state=None,
-                 sync_state=True,
-                 device_name=None,
-                 feature_name=None,
-                 after_update_cb=None):
+    def __init__(
+        self,
+        xknx,
+        group_address=None,
+        group_address_state=None,
+        sync_state=True,
+        device_name=None,
+        feature_name=None,
+        after_update_cb=None,
+    ):
         """Initialize RemoteValue class."""
         # pylint: disable=too-many-arguments
         self.xknx = xknx
-        if isinstance(group_address, (str, int)):
+        if group_address is not None:
             group_address = GroupAddress(group_address)
-        if isinstance(group_address_state, (str, int)):
+        if group_address_state is not None:
             group_address_state = GroupAddress(group_address_state)
 
         self.group_address = group_address
         self.group_address_state = group_address_state
-        self.device_name = "Unknown" \
-            if device_name is None else device_name
-        self.feature_name = "Unknown" \
-            if feature_name is None else feature_name
+        self.device_name = "Unknown" if device_name is None else device_name
+        self.feature_name = "Unknown" if feature_name is None else feature_name
         self.after_update_cb = after_update_cb
         self.payload = None
 
         if sync_state and self.group_address_state:
-            self.xknx.state_updater.register_remote_value(self, tracker_options=sync_state)
+            self.xknx.state_updater.register_remote_value(
+                self, tracker_options=sync_state
+            )
 
     def __del__(self):
         """Destructor. Removing self from StateUpdater if was registered."""
@@ -57,12 +59,12 @@ class RemoteValue():
     @property
     def readable(self):
         """Evaluate if remote value should be read from bus."""
-        return isinstance(self.group_address_state, GroupAddress)
+        return bool(self.group_address_state)
 
     @property
     def writable(self):
         """Evaluate if remote value has a group_address set."""
-        return isinstance(self.group_address, GroupAddress)
+        return bool(self.group_address)
 
     def has_group_address(self, group_address):
         """Test if device has given group address."""
@@ -71,32 +73,39 @@ class RemoteValue():
     def payload_valid(self, payload):
         """Test if telegram payload may be parsed - to be implemented in derived class.."""
         # pylint: disable=unused-argument
-        self.xknx.logger.warning("payload_valid not implemented for %s", self.__class__.__name__)
+        self.xknx.logger.warning(
+            "'payload_valid()' not implemented for %s", self.__class__.__name__
+        )
         return True
 
     def from_knx(self, payload):
         """Convert current payload to value - to be implemented in derived class."""
         # pylint: disable=unused-argument
-        self.xknx.logger.warning("from_knx not implemented for %s", self.__class__.__name__)
+        self.xknx.logger.warning(
+            "'from_knx()' not implemented for %s", self.__class__.__name__
+        )
 
     def to_knx(self, value):
         """Convert value to payload - to be implemented in derived class."""
         # pylint: disable=unused-argument
-        self.xknx.logger.warning("to_knx not implemented for %s", self.__class__.__name__)
+        self.xknx.logger.warning(
+            "'to_knx()' not implemented for %s", self.__class__.__name__
+        )
 
     async def process(self, telegram, always_callback=False):
         """Process incoming telegram."""
         if not self.has_group_address(telegram.group_address):
             return False
         if not self.payload_valid(telegram.payload):
-            raise CouldNotParseTelegram("payload invalid",
-                                        payload=telegram.payload,
-                                        group_address=telegram.group_address,
-                                        device_name=self.device_name,
-                                        feature_name=self.feature_name)
+            raise CouldNotParseTelegram(
+                "payload invalid",
+                payload=telegram.payload,
+                group_address=telegram.group_address,
+                device_name=self.device_name,
+                feature_name=self.feature_name,
+            )
         self.xknx.state_updater.update_received(self)
-        if self.payload is None or always_callback \
-                or self.payload != telegram.payload:
+        if self.payload is None or always_callback or self.payload != telegram.payload:
             self.payload = telegram.payload
             if self.after_update_cb is not None:
                 await self.after_update_cb()
@@ -111,22 +120,32 @@ class RemoteValue():
 
     async def send(self, response=False):
         """Send payload as telegram to KNX bus."""
-        telegram = Telegram()
-        telegram.group_address = self.group_address
-        telegram.telegramtype = TelegramType.GROUP_RESPONSE \
-            if response else TelegramType.GROUP_WRITE
-        telegram.payload = self.payload
+        telegram = Telegram(
+            group_address=self.group_address,
+            telegramtype=(
+                TelegramType.GROUP_RESPONSE if response else TelegramType.GROUP_WRITE
+            ),
+            payload=self.payload,
+        )
         await self.xknx.telegrams.put(telegram)
 
     async def set(self, value, response=False):
         """Set new value."""
         if not self.initialized:
-            self.xknx.logger.info("Setting value of uninitialized device: %s - %s (value: %s)",
-                                  self.device_name, self.feature_name, value)
+            self.xknx.logger.info(
+                "Setting value of uninitialized device: %s - %s (value: %s)",
+                self.device_name,
+                self.feature_name,
+                value,
+            )
             return
         if not self.writable:
-            self.xknx.logger.warning("Attempted to set value for non-writable device: %s - %s (value: %s)",
-                                     self.device_name, self.feature_name, value)
+            self.xknx.logger.warning(
+                "Attempted to set value for non-writable device: %s - %s (value: %s)",
+                self.device_name,
+                self.feature_name,
+                value,
+            )
             return
 
         payload = self.to_knx(value)  # pylint: disable=assignment-from-no-return
@@ -144,6 +163,7 @@ class RemoteValue():
             self.xknx.logger.debug("Sync %s - %s", self.device_name, self.feature_name)
             # pylint: disable=import-outside-toplevel
             from xknx.core import ValueReader
+
             value_reader = ValueReader(self.xknx, self.group_address_state)
             if wait_for_result:
                 telegram = await value_reader.read()
@@ -151,8 +171,11 @@ class RemoteValue():
                     await self.process(telegram)
                 else:
                     self.xknx.logger.warning(
-                        "Could not sync group address '%s' for %s - %s",
-                        self.group_address_state, self.device_name, self.feature_name)
+                        "Could not sync group address '%s' (%s - %s)",
+                        self.group_address_state,
+                        self.device_name,
+                        self.feature_name,
+                    )
             else:
                 await value_reader.send_group_read()
 
@@ -163,11 +186,12 @@ class RemoteValue():
 
     def group_addr_str(self):
         """Return object as readable string."""
-        return '{0}/{1}/{2}/{3}' \
-            .format(self.group_address.__repr__(),
-                    self.group_address_state.__repr__(),
-                    self.payload,
-                    self.value)
+        return "{}/{}/{}/{}".format(
+            self.group_address.__repr__(),
+            self.group_address_state.__repr__(),
+            self.payload,
+            self.value,
+        )
 
     def __str__(self):
         """Return object as string representation."""
@@ -175,7 +199,8 @@ class RemoteValue():
             self.__class__.__name__,
             self.device_name,
             self.feature_name,
-            self.group_addr_str())
+            self.group_addr_str(),
+        )
 
     def __eq__(self, other):
         """Equal operator."""
